Shuttle’s implementation of an async executor, roughly equivalent to futures::executor.
The spawn method spawns a new asynchronous task that the executor will run to completion. The block_on method blocks the current thread on the completion of a future.
Modules
- batch_
semaphore - A counting semaphore supporting both async and sync operations.
Structs
- Abort
Handle - An owned permission to abort a spawned task, without awaiting its completion.
- Join
Handle - An owned permission to join on an async task (await its termination).
Enums
- Join
Error - Task failed to execute to completion.
Functions
- block_
on - Run a future to completion on the current thread.
- spawn
- Spawn a new async task that the executor will run to completion.
- spawn_
local - Spawn a new async task that the executor will run to completion.
This is just
spawnwithout theSendbound, and it mirrorsspawn_localfrom Tokio. - yield_
now - Yields execution back to the scheduler.