A synchronization primitive which can be used to run a one-time global initialization. Useful
for one-time initialization for FFI or related functionality. This type can only be constructed
with Once::new().
A stable signature for identifying resources in Shuttle tests.
This is used internally to track and differentiate between different resource instances
across shuttle iterations. This signature hash is not guaranteed to be unique (two
different resources may have the same hash). In particular, resources which provide
const constructors cannot provide any runtime context to their signatures, so any
two resources created at the same source location will collide.
An enumeration of possible errors associated with a TryLockResult which
can occur while trying to acquire a lock, from the try_lock method on a
Mutex or the try_read and try_write methods on an RwLock.