pub struct AtomicBool { /* private fields */ }Expand description
A boolean type which can be safely shared between threads.
Implementations
Sourceimpl AtomicBool
impl AtomicBool
Sourcepub fn into_inner(self) -> bool
pub fn into_inner(self) -> bool
Consumes the atomic and returns the contained value.
Sourcepub fn swap(&self, val: bool, order: Ordering) -> bool
pub fn swap(&self, val: bool, order: Ordering) -> bool
Stores a value into the atomic boolean, returning the previous value.
Sourcepub fn fetch_update<F>(
&self,
set_order: Ordering,
fetch_order: Ordering,
f: F,
) -> Result<bool, bool>
pub fn fetch_update<F>( &self, set_order: Ordering, fetch_order: Ordering, f: F, ) -> Result<bool, bool>
Fetches the value, and applies a function to it that returns an optional new value.
Returns a Result of Ok(previous_value) if the function returned Some(_), else
Err(previous_value).
Sourcepub fn compare_and_swap(
&self,
current: bool,
new: bool,
order: Ordering,
) -> bool
👎Deprecated since 0.0.6: Use compare_exchange or compare_exchange_weak instead
pub fn compare_and_swap( &self, current: bool, new: bool, order: Ordering, ) -> bool
Use compare_exchange or compare_exchange_weak instead
Stores a value into the atomic boolean if the current value is the same as the
current value.
Sourcepub fn compare_exchange(
&self,
current: bool,
new: bool,
success: Ordering,
failure: Ordering,
) -> Result<bool, bool>
pub fn compare_exchange( &self, current: bool, new: bool, success: Ordering, failure: Ordering, ) -> Result<bool, bool>
Stores a value into the atomic boolean if the current value is the same as the
current value.
The return value is a result indicating whether the new value was written and
containing the previous value. On success this value is guaranteed to be equal to
current.
Sourcepub fn compare_exchange_weak(
&self,
current: bool,
new: bool,
success: Ordering,
failure: Ordering,
) -> Result<bool, bool>
pub fn compare_exchange_weak( &self, current: bool, new: bool, success: Ordering, failure: Ordering, ) -> Result<bool, bool>
Stores a value into the atomic boolean if the current value is the same as the
current value.
Unlike AtomicBool::compare_exchange, this function is allowed to spuriously fail
even when the comparison succeeds, which can result in more efficient code on some
platforms. The return value is a result indicating whether the new value was written
and containing the previous value.
Sourcepub fn fetch_and(&self, val: bool, order: Ordering) -> bool
pub fn fetch_and(&self, val: bool, order: Ordering) -> bool
Logical “and” with the current value. Returns the previous value.
Sourcepub fn fetch_nand(&self, val: bool, order: Ordering) -> bool
pub fn fetch_nand(&self, val: bool, order: Ordering) -> bool
Logical “nand” with the current value. Returns the previous value.
Sourcepub fn fetch_or(&self, val: bool, order: Ordering) -> bool
pub fn fetch_or(&self, val: bool, order: Ordering) -> bool
Logical “or” with the current value. Returns the previous value.
Sourcepub fn fetch_xor(&self, val: bool, order: Ordering) -> bool
pub fn fetch_xor(&self, val: bool, order: Ordering) -> bool
Logical “xor” with the current value. Returns the previous value.
Sourcepub unsafe fn raw_load(&self) -> bool
pub unsafe fn raw_load(&self) -> bool
Load the atomic value directly without triggering any Shuttle context switches.
Safety
Shuttle does not consider potential concurrent interleavings of this function call, and so it should be used when those interleavings aren’t important (primarily in debugging scenarios where we might want to just print this atomic’s value).