SyncSender

Struct SyncSender 

pub struct SyncSender<T> { /* private fields */ }
The sending-half of Rust’s synchronous sync_channel type.

Messages can be sent through this channel with SyncSender::send or [try_send] (TODO)

SyncSender::send will block if there is no space in the internal buffer.

Implementations

Source

impl<T> SyncSender<T>

pub fn send(&self, t: T) -> Result<(), SendError<T>>

Sends a value on this synchronous channel.

This function will block until space in the internal buffer becomes available or a receiver is available to hand off the message to.

pub fn try_send(&self, t: T) -> Result<(), TrySendError<T>>

Attempts to send a value on this channel without blocking.

This method differs from send by returning immediately if the channel’s buffer is full or no receiver is waiting to acquire some data. Compared with send, this function has two failure cases instead of one (one for disconnection, one for a full buffer).