pub struct Condvar { /* private fields */ }Expand description
A Condvar represents the ability to block a thread such that it consumes no CPU time while
waiting for an event to occur.
Implementations
Sourceimpl Condvar
impl Condvar
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new condition variable which is ready to be waited on and notified.
Sourcepub fn wait<'a, T>(
&self,
guard: MutexGuard<'a, T>,
) -> LockResult<MutexGuard<'a, T>>
pub fn wait<'a, T>( &self, guard: MutexGuard<'a, T>, ) -> LockResult<MutexGuard<'a, T>>
Blocks the current thread until this condition variable receives a notification.
Sourcepub fn wait_while<'a, T, F>(
&self,
guard: MutexGuard<'a, T>,
condition: F,
) -> LockResult<MutexGuard<'a, T>>
pub fn wait_while<'a, T, F>( &self, guard: MutexGuard<'a, T>, condition: F, ) -> LockResult<MutexGuard<'a, T>>
Blocks the current thread until this condition variable receives a notification and the provided condition is false.
Sourcepub fn wait_timeout<'a, T>(
&self,
guard: MutexGuard<'a, T>,
_dur: Duration,
) -> LockResult<(MutexGuard<'a, T>, WaitTimeoutResult)>
pub fn wait_timeout<'a, T>( &self, guard: MutexGuard<'a, T>, _dur: Duration, ) -> LockResult<(MutexGuard<'a, T>, WaitTimeoutResult)>
Waits on this condition variable for a notification, timing out after a specified duration.
Sourcepub fn wait_timeout_while<'a, T, F>(
&self,
guard: MutexGuard<'a, T>,
_dur: Duration,
condition: F,
) -> LockResult<(MutexGuard<'a, T>, WaitTimeoutResult)>
pub fn wait_timeout_while<'a, T, F>( &self, guard: MutexGuard<'a, T>, _dur: Duration, condition: F, ) -> LockResult<(MutexGuard<'a, T>, WaitTimeoutResult)>
Waits on this condition variable for a notification, timing out after a specified duration.
The semantics of this function are equivalent to wait_while except
that the thread will be blocked for roughly no longer than dur.
Sourcepub fn notify_one(&self)
pub fn notify_one(&self)
Wakes up one blocked thread on this condvar.
If there is a blocked thread on this condition variable, then it will be woken up from its call to wait or wait_timeout. Calls to notify_one are not buffered in any way.
Sourcepub fn notify_all(&self)
pub fn notify_all(&self)
Wakes up all blocked threads on this condvar.