pub struct RwLock<T: ?Sized> { /* private fields */ }Expand description
A reader-writer lock, the same as std::sync::RwLock.
Unlike std::sync::RwLock, the same thread is never allowed to acquire the read side of a
RwLock more than once. The std version is ambiguous about what behavior is allowed here, so
we choose the most conservative one.
Implementations
Sourceimpl<T: ?Sized> RwLock<T>
impl<T: ?Sized> RwLock<T>
Sourcepub fn read(&self) -> LockResult<RwLockReadGuard<'_, T>>
pub fn read(&self) -> LockResult<RwLockReadGuard<'_, T>>
Locks this rwlock with shared read access, blocking the current thread until it can be acquired.
Sourcepub fn write(&self) -> LockResult<RwLockWriteGuard<'_, T>>
pub fn write(&self) -> LockResult<RwLockWriteGuard<'_, T>>
Locks this rwlock with exclusive write access, blocking the current thread until it can be acquired.
Sourcepub fn try_read(&self) -> TryLockResult<RwLockReadGuard<'_, T>>
pub fn try_read(&self) -> TryLockResult<RwLockReadGuard<'_, T>>
Attempts to acquire this rwlock with shared read access.
If the access could not be granted at this time, then Err is returned. This function does not block.
Note that unlike std::sync::RwLock::try_read, if the current thread already holds this
read lock, try_read will return Err.
Sourcepub fn try_write(&self) -> TryLockResult<RwLockWriteGuard<'_, T>>
pub fn try_write(&self) -> TryLockResult<RwLockWriteGuard<'_, T>>
Attempts to acquire this rwlock with shared read access.
If the access could not be granted at this time, then Err is returned. This function does not block.
Sourcepub fn get_mut(&mut self) -> LockResult<&mut T>
pub fn get_mut(&mut self) -> LockResult<&mut T>
Returns a mutable reference to the underlying data.
Since this call borrows the RwLock mutably, no actual locking needs to
take place—the mutable borrow statically guarantees no locks exist.
Sourcepub fn into_inner(self) -> LockResult<T>where
T: Sized,
pub fn into_inner(self) -> LockResult<T>where
T: Sized,
Consumes this RwLock, returning the underlying data
Sourcepub fn clear_poison(&self)
pub fn clear_poison(&self)
Clear the poisoned state from a lock.