yield_now

Function yield_now 

pub fn yield_now()
Cooperatively gives up a timeslice to the Shuttle scheduler.

Some Shuttle schedulers use this as a hint to deprioritize the current thread in order for other threads to make progress (e.g., in a spin loop).