pub fn spawn_local<F>(fut: F) -> JoinHandle<F::Output> ⓘwhere F: Future + 'static, F::Output: 'static,
Spawn a new async task that the executor will run to completion. This is just spawn without the Send bound, and it mirrors spawn_local from Tokio.
spawn
Send
spawn_local