Multi-producer, single-consumer FIFO queue communication primitives.
Structs
- Into
Iter - An owning iterator over messages on a
Receiver, created byinto_iter. - Iter
- An iterator over messages on a
Receiver, created byiter. - Receiver
- The receiving half of Rust’s
channel(orsync_channel) type. This half can only be owned by one thread. - Recv
Error - An error returned from the
recvfunction on aReceiver. - Send
Error - An error returned from the
Sender::sendorSyncSender::sendfunction on channels. - Sender
- The sending-half of Rust’s asynchronous
channeltype. This half can only be owned by one thread, but it can be cloned to send to other threads. - Sync
Sender - The sending-half of Rust’s synchronous
sync_channeltype. - TryIter
- An iterator that attempts to yield all pending values for a
Receiver, created bytry_iter.
Enums
- Recv
Timeout Error - This enumeration is the list of possible errors that made
recv_timeoutunable to return data when called. This can occur with both achanneland async_channel. - TryRecv
Error - This enumeration is the list of the possible reasons that
try_recvcould not return data when called. This can occur with both achanneland async_channel. - TrySend
Error - This enumeration is the list of the possible error outcomes for the
try_sendmethod.
Functions
- channel
- Create an unbounded channel
- sync_
channel - Create a bounded channel